#name: varnish_build.sh
#Preconditions: Local source

function VarnishBuildStart(){
        #create the compile status directory
        StatusDir=/var/log/
        StatusFile=$StatusDir/compile.log
        if [ ! -d "$StatusDir" ]; then
            mkdir -p $StatusDir
        fi
        touch $StatusFile
        echo "compiler running" > $StatusFile
}

function VarnishYumInstall(){
        #install dependency package
        yum install wget make gcc gcc-c++ rpm-build tar autoconf automake jemalloc-devel libedit-devel libtool ncurses-devel pcre-devel pkgconfig python-docutils python-sphinx graphviz -y >> $StatusFile 2>&1
        if [ $? -ne 0 ];then
                echo "compiler error" >> $StatusFile
                echo "yum error!" | tee -a $StatusFile
                exit 1
        fi
}

function VarnishSourceDownload(){
        #download python-3.6.0
        if [ ! -f Python-3.6.0.tgz ];then
                wget -N https://www.python.org/ftp/python/3.6.0/Python-3.6.0.tgz  --no-check-certificate --tries=3 --timeout=300 >> $StatusFile 2>&1
                if [ $? -ne 0 ];then
                        echo "compiler error" >> $StatusFile
                        echo "wget python code failed,begin to confirm if the python code are put in the folder! " | tee -a $StatusFile
                        exit 1        
                fi
        fi

        #download the source packages
        if [ ! -f varnish-6.2.0.tgz ];then
                wget -N https://varnish-cache.org/_downloads/varnish-6.2.0.tgz --no-check-certificate --tries=3 --timeout=300 >> $StatusFile 2>&1
                if [ $? -ne 0 ];then
                        echo "compiler error" >> $StatusFile
                        echo "wget varnish code failed,begin to confirm if the varnish code are put in the folder! "
                        exit 1
                fi
        fi
}

function VarnishDepencyBuild(){
        #make and install python-3.6.0
        sed -i '2 iexit 0' /usr/lib/rpm/brp-python-bytecompile
        mkdir /usr/local/python3 >> $StatusFile 2>&1
        tar -zxvf Python-3.6.0.tgz >> $StatusFile 2>&1
        cd Python-3.6.0
        ./configure --prefix=/usr/local/python3 >> $StatusFile 2>&1
        make -j20 >> $StatusFile 2>&1
        make install -j20 >> $StatusFile 2>&1

        echo $PATH | grep "/usr/local/python3/bin" > /dev/null
        if [ $? -ne 0 ];then
            echo export PATH=\$PATH:/usr/local/python3/bin >> /etc/profile
            source /etc/profile
        fi

        python3 --version >> $StatusFile 2>&1
        cd ../
}

function VarnishRpmBuild(){
        if [ ! -f varnish.spec ];then
                echo "compiler error" >> $StatusFile
                echo "confirm if the varnish.spec is put in the folder! " | tee -a $StatusFile
                exit 1
        fi

        #prepare to build the rpm package
        mkdir -p /root/rpmbuild/SOURCES /root/rpmbuild/SPECS /root/rpmbuild/BUILD /root/rpmbuild/RPMS  /root/rpmbuild/BUILDROOT  /root/rpmbuild/SRPMS
        cp varnish-6.2.0.tgz /root/rpmbuild/SOURCES
        cp varnish.spec /root/rpmbuild/SPECS

        sed -i '/check_files/d' /usr/lib/rpm/macros
        sed -i '/unpackaged_files_terminate_build/d'  /usr/lib/rpm/macros
	
        #start to build the rpm package,the rpm path is /root/rpmbuild/RPMS/aarch64/
        rpmbuild -bb /root/rpmbuild/SPECS/varnish.spec >> $StatusFile 2>&1
        if [ $? -ne 0 ];then
                echo "compiler error" >> $StatusFile
                echo "rpmbuild failed!" | tee -a $StatusFile
                exit 1
        fi

        ls /root/rpmbuild/RPMS/aarch64/ >> $StatusFile 2>&1
}

function VarnishBuildStop(){

        mv /root/rpmbuild/RPMS/aarch64/*.rpm .

        echo "compiler success" | tee -a $StatusFile
}

VarnishBuildStart
VarnishYumInstall
VarnishSourceDownload
VarnishDepencyBuild
VarnishRpmBuild
VarnishBuildStop
