#name: varnish_install.sh
#Preconditions: Local source

function VarnishInstallStart(){
        #create the install status directory
        StatusDir=/var/log/
        StatusFile=$StatusDir/install.log
        if [ ! -d "$StatusDir" ]; then
            mkdir -p $StatusDir
        fi
        touch $StatusFile
        echo "install running" > $StatusFile
}

function VarnishYumInstall(){
        #install dependency package
        yum install wget make gcc gcc-c++ rpm-build tar autoconf automake jemalloc-devel libedit-devel libtool ncurses-devel pcre-devel pkgconfig python-docutils python-sphinx graphviz -y >> $StatusFile 2>&1
        if [ $? -ne 0 ];then
                echo "install error" >> $StatusFile
                echo "yum error!" | tee -a $StatusFile
                exit 1
        fi
}

function VarnishDepencyInstall(){
        #download python-3.6.0
        if [ ! -f Python-3.6.0.tgz ];then
                wget -N https://www.python.org/ftp/python/3.6.0/Python-3.6.0.tgz  --no-check-certificate --tries=3 --timeout=300  >> $StatusFile 2>&1
                if [ $? -ne 0 ];then
                        echo "install error" >> $StatusFile
                        echo "wget python code failed,begin to confirm if the python code are put in the folder! " | tee -a $StatusFile
                        exit 1
                fi
        fi

        #make and install python-3.6.0
        sed -i '2 iexit 0' /usr/lib/rpm/brp-python-bytecompile
        mkdir /usr/local/python3 >> $StatusFile 2>&1
        tar -zxvf Python-3.6.0.tgz >> $StatusFile 2>&1
        cd Python-3.6.0
        ./configure --prefix=/usr/local/python3 >> $StatusFile 2>&1
        make -j20 >> $StatusFile 2>&1
        make install -j20 >> $StatusFile 2>&1

        echo $PATH | grep "/usr/local/python3/bin" > /dev/null
        if [ $? -ne 0 ];then
            echo export PATH=\$PATH:/usr/local/python3/bin >> /etc/profile
            source /etc/profile
        fi

        source /etc/profile
        python3 --version >> $StatusFile 2>&1
        cd ../
}

function VarnishRpmInstall(){
        #check and uninstall
        rpm -qa |grep varnish-6.2.0 >> $StatusFile 2>&1
        if [ $? -ne 1 ];then
                rpm -e --nodeps `rpm -qa |grep varnish-6.2.0`
        fi

        #start to install the rpm to /usr/local/varnish
        rpm -ivh varnish-6.2.0-1.el7.aarch64.rpm  >> $StatusFile 2>&1
        if [ $? -ne 0 ];then
                echo "install error" >> $StatusFile
                echo "rpm install error!" | tee -a $StatusFile
                exit 1
        fi
        ls /usr/local/varnish  >> $StatusFile 2>&1
}

function VarnishInstallStop(){
        echo "$subUnit install success" | tee -a $StatusFile
}

VarnishInstallStart
VarnishYumInstall
VarnishDepencyInstall
VarnishRpmInstall
VarnishInstallStop
